==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/DangereDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 重大事故隐患判定明细E
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_dangere_detail")
public class DangereDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="danger_id")
    private Long dangerId; // 主表主键ID
    @TableField(value="detail_code")
    private Long detailCode; // 隐患编号
    @TableField(value="detail_type")
    private String detailType; // 隐患类别
    @TableField(value="detail_management_link")
    private String detailManagementLink; // 管理环节
    @TableField(value="detail_content")
    private String detailContent; // 隐患内容
    @TableField(value="detail_self_check")
    private String detailSelfCheck; // 自查情况
    @TableField(value="detail_result")
    private String detailResult; // 判定结果
    @TableField(value="detail_description")
    private String detailDescription; // 备注
    
    
    

    public Long getDangerId() {
        return dangerId;
    }

    public void setDangerId(Long dangerId) {
        this.dangerId = dangerId;
    }
    public Long getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(Long detailCode) {
        this.detailCode = detailCode;
    }
    public String getDetailType() {
        return detailType;
    }

    public void setDetailType(String detailType) {
        this.detailType = detailType;
    }
    public String getDetailManagementLink() {
        return detailManagementLink;
    }

    public void setDetailManagementLink(String detailManagementLink) {
        this.detailManagementLink = detailManagementLink;
    }
    public String getDetailContent() {
        return detailContent;
    }

    public void setDetailContent(String detailContent) {
        this.detailContent = detailContent;
    }
    public String getDetailSelfCheck() {
        return detailSelfCheck;
    }

    public void setDetailSelfCheck(String detailSelfCheck) {
        this.detailSelfCheck = detailSelfCheck;
    }
    public String getDetailResult() {
        return detailResult;
    }

    public void setDetailResult(String detailResult) {
        this.detailResult = detailResult;
    }
    public String getDetailDescription() {
        return detailDescription;
    }

    public void setDetailDescription(String detailDescription) {
        this.detailDescription = detailDescription;
    }
    
}

==> ejc-jltest-impl-3.0.0-20240328.015927-125-sources.jar: com/ejianc/business/jltest/orgtest/bean/DangereDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 重大事故隐患判定明细E
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_dangere_detail")
public class DangereDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="danger_id")
    private Long dangerId; // 主表主键ID
    @TableField(value="detail_code")
    private Long detailCode; // 隐患编号
    @TableField(value="detail_type")
    private Long detailType; // 隐患类别
    @TableField(value="detail_management_link")
    private String detailManagementLink; // 管理环节
    @TableField(value="detail_content")
    private String detailContent; // 隐患内容
    @TableField(value="detail_self_check")
    private String detailSelfCheck; // 自查情况
    @TableField(value="detail_result")
    private String detailResult; // 判定结果
    @TableField(value="detail_description")
    private String detailDescription; // 备注
    
    
    

    public Long getDangerId() {
        return dangerId;
    }

    public void setDangerId(Long dangerId) {
        this.dangerId = dangerId;
    }
    public Long getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(Long detailCode) {
        this.detailCode = detailCode;
    }

    public Long getDetailType() {
        return detailType;
    }

    public void setDetailType(Long detailType) {
        this.detailType = detailType;
    }

    public String getDetailManagementLink() {
        return detailManagementLink;
    }

    public void setDetailManagementLink(String detailManagementLink) {
        this.detailManagementLink = detailManagementLink;
    }
    public String getDetailContent() {
        return detailContent;
    }

    public void setDetailContent(String detailContent) {
        this.detailContent = detailContent;
    }
    public String getDetailSelfCheck() {
        return detailSelfCheck;
    }

    public void setDetailSelfCheck(String detailSelfCheck) {
        this.detailSelfCheck = detailSelfCheck;
    }
    public String getDetailResult() {
        return detailResult;
    }

    public void setDetailResult(String detailResult) {
        this.detailResult = detailResult;
    }
    public String getDetailDescription() {
        return detailDescription;
    }

    public void setDetailDescription(String detailDescription) {
        this.detailDescription = detailDescription;
    }
    
}
